Introduction
============

.. image:: https://travis-ci.org/propertyshelf/plone.mls.core.png?branch=master
   :target: http://travis-ci.org/propertyshelf/plone.mls.core

Plone support for the Propertyshelf MLS.
